@@ -40,7 +40,7 @@
 #include "structmember.h"
 
 #if PY_MAJOR_VERSION >= 3
-   #define PyInt_FromSize_t(x) PyLong_FromSize_t(x) 
+   #define PyInt_FromSize_t(x) PyLong_FromSize_t(x)
 #endif
 
 #define CHECK(cond, ...) if (LZ4F_isError(cond)) { printf("%s%s", "Error => ", LZ4F_getErrorName(cond)); goto _output_error; }
@@ -107,28 +107,61 @@ static PyObject *py_lz4f_compressFrame(PyObject *self, PyObject *args) {
     return result;
 }
 
+
+static PyObject *py_lz4f_makePrefs(PyObject *self, PyObject *args, PyObject *keywds) {
+    LZ4F_frameInfo_t frameInfo;
+    LZ4F_preferences_t* prefs;
+    PyObject *result = PyDict_New();
+    static char *kwlist[] = {"blockSizeID", "blockMode", "chkFlag"
+                             "autoFlush"};
+    unsigned int blkID=7;
+    unsigned int blkMode=1;
+    unsigned int chkSumFlag=0;
+//    unsigned int compLevel=0; //For future expansion
+    unsigned int autoFlush=0;
+
+    (void)self;
+    if (!PyArg_ParseTupleAndKeywords(args, keywds, "|IIII", kwlist, &blkID,
+                                     &blkMode, &chkSumFlag, &autoFlush)) {
+        return NULL;
+    }
+
+    //fprintf(stdout, "blkID: %u As self.", blkID);
+    prefs = calloc(1,sizeof(LZ4F_preferences_t));
+    frameInfo = (LZ4F_frameInfo_t){blkID, blkMode, chkSumFlag, {0}};
+    prefs->frameInfo = frameInfo;
+    prefs->autoFlush = autoFlush;
+    result = PyCapsule_New(prefs, NULL, NULL);
+
+    return result;
+//_output_error:
+//    return Py_None;
+}
+
 static PyObject *py_lz4f_compressBegin(PyObject *self, PyObject *args) {
     char* dest;
     LZ4F_compressionContext_t cCtx;
-    LZ4F_preferences_t prefs = {{0}, 0, 0, {0}};
+    LZ4F_preferences_t prefs = {{7, 0, 0, {0}}, 0, 0, {0}};
+    LZ4F_preferences_t* prefsPtr = &prefs;
     PyObject *result;
     PyObject *py_cCtx;
+    PyObject *py_prefsPtr = NULL;
     size_t dest_size;
     size_t final_size;
 
     (void)self;
-    if (!PyArg_ParseTuple(args, "O", &py_cCtx)) {
+    if (!PyArg_ParseTuple(args, "O|O", &py_cCtx, &py_prefsPtr)) {
         return NULL;
     }
 
     cCtx = (LZ4F_compressionContext_t)PyCapsule_GetPointer(py_cCtx, NULL);
     dest_size = 19;
     dest = (char*)malloc(dest_size);
+    if (py_prefsPtr != NULL) {
+        prefsPtr = (LZ4F_preferences_t*)PyCapsule_GetPointer(py_prefsPtr, NULL);
+    }
 
-    prefs.frameInfo.blockMode = 1;
-    prefs.frameInfo.blockSizeID = 7;
-    //fprintf(stdout, "BlockMode: %i\n", prefs.frameInfo.blockMode);
-    final_size = LZ4F_compressBegin(cCtx, dest, dest_size, &prefs);
+    final_size = LZ4F_compressBegin(cCtx, dest, dest_size, prefsPtr);
     CHECK(final_size);
     result = PyBytes_FromStringAndSize(dest, final_size);
 
@@ -240,6 +273,7 @@ static PyObject *py_lz4f_getFrameInfo(PyObject *self, PyObject *args) {
     LZ4F_frameInfo_t frameInfo;
     PyObject *blkSize;
     PyObject *blkMode;
+    PyObject *contChkFlag;
     PyObject *py_dCtx;
     PyObject *result = PyDict_New();
     size_t ssrc_size;
@@ -258,8 +292,10 @@ static PyObject *py_lz4f_getFrameInfo(PyObject *self, PyObject *args) {
 
     blkSize = PyInt_FromSize_t(frameInfo.blockSizeID);
     blkMode = PyInt_FromSize_t(frameInfo.blockMode);
+    contChkFlag = PyInt_FromSize_t(frameInfo.contentChecksumFlag);
     PyDict_SetItemString(result, "blkSize", blkSize);
     PyDict_SetItemString(result, "blkMode", blkMode);
+    PyDict_SetItemString(result, "chkFlag", contChkFlag);
 
 
     return result;
@@ -329,6 +365,7 @@ _output_error:
 static PyMethodDef Lz4fMethods[] = {
     {"createCompContext",   py_lz4f_createCompCtx,   METH_VARARGS, CCCTX_DOCSTRING},
     {"compressFrame",       py_lz4f_compressFrame,   METH_VARARGS, COMPF_DOCSTRING},
+    {"makePrefs",  (PyCFunction)py_lz4f_makePrefs,   METH_VARARGS | METH_KEYWORDS, NULL},
     {"compressBegin",       py_lz4f_compressBegin,   METH_VARARGS, COMPB_DOCSTRING},
     {"compressUpdate",      py_lz4f_compressUpdate,  METH_VARARGS, COMPU_DOCSTRING},
     {"compressEnd",         py_lz4f_compressEnd,     METH_VARARGS, COMPE_DOCSTRING},
